@@ -1,7 +1,6 @@
 // Predefined symbols and macros -*- C++ -*-
 
-// Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
-// 2006, 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
+// Copyright (C) 1997-2013 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -32,7 +31,7 @@
 #define _GLIBCXX_CXX_CONFIG_H 1
 
 // The current version of the C++ library in compressed ISO date format.
-#define __GLIBCXX__ 20120301
+#define __GLIBCXX__ 20130531
 
 // Macros for various attributes.
 //   _GLIBCXX_PURE
@@ -52,10 +51,9 @@
 # define _GLIBCXX_NORETURN __attribute__ ((__noreturn__))
 #endif
 
+// See below for C++
 #ifndef _GLIBCXX_NOTHROW
-# ifdef __cplusplus
-#  define _GLIBCXX_NOTHROW throw()
-# else
+# ifndef __cplusplus
 #  define _GLIBCXX_NOTHROW __attribute__((__nothrow__))
 # endif
 #endif
@@ -80,7 +78,7 @@
 # define _GLIBCXX_USE_DEPRECATED 1
 #endif
 
-#if defined(__DEPRECATED) && defined(__GXX_EXPERIMENTAL_CXX0X__)
+#if defined(__DEPRECATED) && (__cplusplus >= 201103L)
 # define _GLIBCXX_DEPRECATED __attribute__ ((__deprecated__))
 #else
 # define _GLIBCXX_DEPRECATED
@@ -90,7 +88,7 @@
 
 // Macro for constexpr, to support in mixed 03/0x mode.
 #ifndef _GLIBCXX_CONSTEXPR
-# ifdef __GXX_EXPERIMENTAL_CXX0X__
+# if __cplusplus >= 201103L
 #  define _GLIBCXX_CONSTEXPR constexpr
 #  define _GLIBCXX_USE_CONSTEXPR constexpr
 # else
@@ -99,6 +97,31 @@
 # endif
 #endif
 
+// Macro for noexcept, to support in mixed 03/0x mode.
+#ifndef _GLIBCXX_NOEXCEPT
+# if __cplusplus >= 201103L
+#  define _GLIBCXX_NOEXCEPT noexcept
+#  define _GLIBCXX_USE_NOEXCEPT noexcept
+#  define _GLIBCXX_THROW(_EXC)
+# else
+#  define _GLIBCXX_NOEXCEPT
+#  define _GLIBCXX_USE_NOEXCEPT throw()
+#  define _GLIBCXX_THROW(_EXC) throw(_EXC)
+# endif
+#endif
+
+#ifndef _GLIBCXX_NOTHROW
+# define _GLIBCXX_NOTHROW _GLIBCXX_USE_NOEXCEPT
+#endif
+
+#ifndef _GLIBCXX_THROW_OR_ABORT
+# if __EXCEPTIONS
+#  define _GLIBCXX_THROW_OR_ABORT(_EXC) (throw (_EXC))
+# else
+#  define _GLIBCXX_THROW_OR_ABORT(_EXC) (__builtin_abort())
+# endif
+#endif
+
 // Macro for extern template, ie controling template linkage via use
 // of extern keyword on template declaration. As documented in the g++
 // manual, it inhibits all implicit instantiations and is used
@@ -132,6 +155,8 @@
       namespace __detail { }
     }
 
+    namespace tr2 { }
+    
     namespace decimal { }
 
     namespace chrono { }
@@ -155,7 +180,7 @@ namespace std
   typedef __SIZE_TYPE__ 	size_t;
   typedef __PTRDIFF_TYPE__	ptrdiff_t;
 
-#ifdef __GXX_EXPERIMENTAL_CXX0X__
+#if __cplusplus >= 201103L
   typedef decltype(nullptr)	nullptr_t;
 #endif
 }
@@ -181,6 +206,9 @@ namespace std
     namespace __detail { inline namespace __7 { } }
   }
 
+  namespace tr2
+  { inline namespace __7 { } }
+
   namespace decimal { inline namespace __7 { } }
 
   namespace chrono { inline namespace __7 { } }
@@ -189,7 +217,6 @@ namespace std
   namespace this_thread { inline namespace __7 { } }
 
   namespace __detail { inline namespace __7 { } }
-  namespace __regex { inline namespace __7 { } }
 }
 
 namespace __gnu_cxx
@@ -267,9 +294,9 @@ namespace std
 # define _GLIBCXX_BEGIN_NAMESPACE_CONTAINER \
 	 namespace _GLIBCXX_STD_C { _GLIBCXX_BEGIN_NAMESPACE_VERSION
 # define _GLIBCXX_END_NAMESPACE_CONTAINER \
-	 } _GLIBCXX_END_NAMESPACE_VERSION
+	 _GLIBCXX_END_NAMESPACE_VERSION }
 # undef _GLIBCXX_EXTERN_TEMPLATE
-#  define _GLIBCXX_EXTERN_TEMPLATE 1 -1
+# define _GLIBCXX_EXTERN_TEMPLATE -1
 #endif
 
 #ifdef _GLIBCXX_PARALLEL
@@ -277,7 +304,7 @@ namespace std
 # define _GLIBCXX_BEGIN_NAMESPACE_ALGO \
 	 namespace _GLIBCXX_STD_A { _GLIBCXX_BEGIN_NAMESPACE_VERSION
 # define _GLIBCXX_END_NAMESPACE_ALGO \
-	 } _GLIBCXX_END_NAMESPACE_VERSION
+	 _GLIBCXX_END_NAMESPACE_VERSION }
 #endif
 
 #ifndef _GLIBCXX_STD_A
@@ -460,6 +487,9 @@ namespace std
 /* Define to 1 if you have the `atanl' function. */
 #define _GLIBCXX_HAVE_ATANL 1
 
+/* Define to 1 if you have the `at_quick_exit' function. */
+/* #undef _GLIBCXX_HAVE_AT_QUICK_EXIT */
+
 /* Define to 1 if the target assembler supports thread-local storage. */
 /* #undef _GLIBCXX_HAVE_CC_TLS */
 
@@ -493,6 +523,9 @@ namespace std
 /* Define if ECANCELED exists. */
 #define _GLIBCXX_HAVE_ECANCELED 1
 
+/* Define if ECHILD exists. */
+#define _GLIBCXX_HAVE_ECHILD 1
+
 /* Define if EIDRM exists. */
 #define _GLIBCXX_HAVE_EIDRM 1
 
@@ -505,6 +538,9 @@ namespace std
 /* Define if ENOLINK exists. */
 /* #undef _GLIBCXX_HAVE_ENOLINK */
 
+/* Define if ENOSPC exists. */
+#define _GLIBCXX_HAVE_ENOSPC 1
+
 /* Define if ENOSR exists. */
 /* #undef _GLIBCXX_HAVE_ENOSR */
 
@@ -523,15 +559,24 @@ namespace std
 /* Define if EOWNERDEAD exists. */
 /* #undef _GLIBCXX_HAVE_EOWNERDEAD */
 
+/* Define if EPERM exists. */
+#define _GLIBCXX_HAVE_EPERM 1
+
 /* Define if EPROTO exists. */
 /* #undef _GLIBCXX_HAVE_EPROTO */
 
 /* Define if ETIME exists. */
 /* #undef _GLIBCXX_HAVE_ETIME */
 
+/* Define if ETIMEDOUT exists. */
+#define _GLIBCXX_HAVE_ETIMEDOUT 1
+
 /* Define if ETXTBSY exists. */
 #define _GLIBCXX_HAVE_ETXTBSY 1
 
+/* Define if EWOULDBLOCK exists. */
+#define _GLIBCXX_HAVE_EWOULDBLOCK 1
+
 /* Define to 1 if you have the <execinfo.h> header file. */
 #define _GLIBCXX_HAVE_EXECINFO_H 1
 
@@ -589,9 +634,8 @@ namespace std
 /* Define if _Unwind_GetIPInfo is available. */
 #define _GLIBCXX_HAVE_GETIPINFO 1
 
-/* Define if gthr-default.h exists (meaning that threading support is
-   enabled). */
-#define _GLIBCXX_HAVE_GTHR_DEFAULT 1
+/* Define if gets is available in <stdio.h>. */
+#define _GLIBCXX_HAVE_GETS 1
 
 /* Define to 1 if you have the `hypot' function. */
 #define _GLIBCXX_HAVE_HYPOT 1
@@ -722,6 +766,9 @@ namespace std
 /* Define to 1 if you have the `qfpclass' function. */
 /* #undef _GLIBCXX_HAVE_QFPCLASS */
 
+/* Define to 1 if you have the `quick_exit' function. */
+/* #undef _GLIBCXX_HAVE_QUICK_EXIT */
+
 /* Define to 1 if you have the `setenv' function. */
 #define _GLIBCXX_HAVE_SETENV 1
 
@@ -746,12 +793,18 @@ namespace std
 /* Define to 1 if you have the `sinl' function. */
 #define _GLIBCXX_HAVE_SINL 1
 
+/* Defined if sleep exists. */
+#define _GLIBCXX_HAVE_SLEEP 1
+
 /* Define to 1 if you have the `sqrtf' function. */
 #define _GLIBCXX_HAVE_SQRTF 1
 
 /* Define to 1 if you have the `sqrtl' function. */
 #define _GLIBCXX_HAVE_SQRTL 1
 
+/* Define to 1 if you have the <stdalign.h> header file. */
+/* #undef _GLIBCXX_HAVE_STDALIGN_H */
+
 /* Define to 1 if you have the <stdbool.h> header file. */
 #define _GLIBCXX_HAVE_STDBOOL_H 1
 
@@ -807,12 +860,18 @@ namespace std
 /* Define to 1 if you have the <sys/resource.h> header file. */
 #define _GLIBCXX_HAVE_SYS_RESOURCE_H 1
 
+/* Define to 1 if you have a suitable <sys/sdt.h> header file */
+/* #undef _GLIBCXX_HAVE_SYS_SDT_H */
+
 /* Define to 1 if you have the <sys/sem.h> header file. */
 #define _GLIBCXX_HAVE_SYS_SEM_H 1
 
 /* Define to 1 if you have the <sys/stat.h> header file. */
 #define _GLIBCXX_HAVE_SYS_STAT_H 1
 
+/* Define to 1 if you have the <sys/sysinfo.h> header file. */
+/* #undef _GLIBCXX_HAVE_SYS_SYSINFO_H */
+
 /* Define to 1 if you have the <sys/time.h> header file. */
 #define _GLIBCXX_HAVE_SYS_TIME_H 1
 
@@ -849,6 +908,9 @@ namespace std
 /* Define to 1 if you have the <unistd.h> header file. */
 #define _GLIBCXX_HAVE_UNISTD_H 1
 
+/* Defined if usleep exists. */
+#define _GLIBCXX_HAVE_USLEEP 1
+
 /* Defined if vfwscanf exists. */
 #define _GLIBCXX_HAVE_VFWSCANF 1
 
@@ -867,8 +929,11 @@ namespace std
 /* Define to 1 if you have the <wctype.h> header file. */
 #define _GLIBCXX_HAVE_WCTYPE_H 1
 
+/* Defined if Sleep exists. */
+/* #undef _GLIBCXX_HAVE_WIN32_SLEEP */
+
 /* Define if writev is available in <sys/uio.h>. */
-/* #undef _GLIBCXX_HAVE_WRITEV */
+#define _GLIBCXX_HAVE_WRITEV 1
 
 /* Define to 1 if you have the `_acosf' function. */
 /* #undef _GLIBCXX_HAVE__ACOSF */
@@ -1056,6 +1121,9 @@ namespace std
 /* Define to 1 if you have the `_tanl' function. */
 /* #undef _GLIBCXX_HAVE__TANL */
 
+/* Define to 1 if you have the `__cxa_thread_atexit_impl' function. */
+/* #undef _GLIBCXX_HAVE___CXA_THREAD_ATEXIT_IMPL */
+
 /* Define as const if the declaration of iconv() needs const. */
 /* #undef _GLIBCXX_ICONV_CONST */
 
@@ -1105,25 +1173,15 @@ namespace std
 /* Version number of package */
 /* #undef _GLIBCXX_VERSION */
 
-/* Define if builtin atomic operations for bool are supported on this host. */
-#define _GLIBCXX_ATOMIC_BUILTINS_1 1
-
-/* Define if builtin atomic operations for short are supported on this host.
-   */
-#define _GLIBCXX_ATOMIC_BUILTINS_2 1
-
-/* Define if builtin atomic operations for int are supported on this host. */
-#define _GLIBCXX_ATOMIC_BUILTINS_4 1
-
-/* Define if builtin atomic operations for long long are supported on this
-   host. */
-#define _GLIBCXX_ATOMIC_BUILTINS_8 1
+/* Define if the compiler supports C++11 atomics. */
+#define _GLIBCXX_ATOMIC_BUILTINS 1
 
 /* Define to use concept checking code from the boost libraries. */
 /* #undef _GLIBCXX_CONCEPT_CHECKS */
 
-/* Define if a fully dynamic basic_string is wanted. */
-/* #undef _GLIBCXX_FULLY_DYNAMIC_STRING */
+/* Define to 1 if a fully dynamic basic_string is wanted, 0 to disable,
+   undefined for platform defaults */
+#define _GLIBCXX_FULLY_DYNAMIC_STRING 0
 
 /* Define if gthreads library is available. */
 #define _GLIBCXX_HAS_GTHREADS 1
@@ -1214,6 +1272,9 @@ namespace std
 /* Defined if clock_gettime has monotonic clock support. */
 /* #undef _GLIBCXX_USE_CLOCK_MONOTONIC */
 
+/* Defined if clock_gettime syscall has monotonic and realtime clock support. */
+/* #undef _GLIBCXX_USE_CLOCK_GETTIME_SYSCALL */
+
 /* Defined if clock_gettime has realtime clock support. */
 /* #undef _GLIBCXX_USE_CLOCK_REALTIME */
 
@@ -1221,9 +1282,18 @@ namespace std
    this host. */
 /* #undef _GLIBCXX_USE_DECIMAL_FLOAT */
 
+/* Define if __float128 is supported on this host. */
+/* #undef _GLIBCXX_USE_FLOAT128 */
+
 /* Defined if gettimeofday is available. */
 #define _GLIBCXX_USE_GETTIMEOFDAY 1
 
+/* Define if get_nprocs is available in <sys/sysinfo.h>. */
+/* #undef _GLIBCXX_USE_GET_NPROCS */
+
+/* Define if __int128 is supported on this host. */
+#define _GLIBCXX_USE_INT128 1
+
 /* Define if LFS support is available. */
 /* #undef _GLIBCXX_USE_LFS */
 
@@ -1236,6 +1306,9 @@ namespace std
 /* Define if NLS translations are to be used. */
 /* #undef _GLIBCXX_USE_NLS */
 
+/* Define if pthreads_num_processors_np is available in <pthread.h>. */
+/* #undef _GLIBCXX_USE_PTHREADS_NUM_PROCESSORS_NP */
+
 /* Define if /dev/random and /dev/urandom are available for the random_device
    of TR1 (Chapter 5.1). */
 #define _GLIBCXX_USE_RANDOM_TR1 1
@@ -1243,9 +1316,27 @@ namespace std
 /* Defined if sched_yield is available. */
 /* #undef _GLIBCXX_USE_SCHED_YIELD */
 
+/* Define if _SC_NPROCESSORS_ONLN is available in <unistd.h>. */
+#define _GLIBCXX_USE_SC_NPROCESSORS_ONLN 1
+
+/* Define if _SC_NPROC_ONLN is available in <unistd.h>. */
+/* #undef _GLIBCXX_USE_SC_NPROC_ONLN */
+
+/* Define if sysctl(), CTL_HW and HW_NCPU are available in <sys/sysctl.h>. */
+/* #undef _GLIBCXX_USE_SYSCTL_HW_NCPU */
+
 /* Define if code specialized for wchar_t should be used. */
 #define _GLIBCXX_USE_WCHAR_T 1
 
+/* Define to 1 if a verbose library is built, or 0 otherwise. */
+#define _GLIBCXX_VERBOSE 1
+
+/* Defined if as can handle rdrand. */
+/* #undef _GLIBCXX_X86_RDRAND */
+
+/* Define to 1 if mutex_timedlock is available. */
+#define _GTHREAD_USE_MUTEX_TIMEDLOCK 1
+
 #if defined (_GLIBCXX_HAVE__ACOSF) && ! defined (_GLIBCXX_HAVE_ACOSF)
 # define _GLIBCXX_HAVE_ACOSF 1
 # define acosf _acosf
